@@ -6,9 +6,10 @@ import datetime
 import os.path
 import shutil
 import pkg_resources
+from six import u
 from starterpyth import defaults
 from starterpyth.fields import RegexpInput, CharInput, ChoiceInput, BooleanInput
-from starterpyth.utils import py3k_unicode, normalize_str
+from starterpyth.utils import normalize_str
 
 __author__ = 'd9pouces'
 
@@ -22,20 +23,20 @@ licenses = [('cecill a', 'cecill_a'), ('cecill b', 'cecill_b'), ('cecill c', 'ce
 license_names = {
     'cecill_a': 'CeCILL-A', 'cecill_b': 'CeCILL-B', 'cecill_c': 'CeCILL-C', 'lgpl_2': 'LGPL 2',
     'lgpl_3': 'LGPL 3', 'gpl_2': 'GPL 2', 'gpl 3': 'GPL 3', 'Other': 'Other license',
-    'apache_2' : 'Apache 2.0', 'mit' : 'MIT', 'bsd_2_clauses' : 'BSD 2 Clauses',
+    'apache_2': 'Apache 2.0', 'mit': 'MIT', 'bsd_2_clauses': 'BSD 2 Clauses',
 }
 pyversions = [('2.6', 2.6), ('2.7', 2.7), ('3.0', 3.0), ('3.1', 3.1), ('3.2', 3.2), ('3.3', 3.3), ('3.4', 3.4)]
 
 
 class BasePlugin(Plugin):
     def update_global_context(self, context, filters):
-        project_name = RegexpInput(_('Project name'), regexp=r'[A-Za-z]\w*', default='Project').input()
+        project_name = RegexpInput(_('Project name'), regexp=r'[A-Za-z]\w*', default=u('Project')).input()
         module_name = RegexpInput(_('Python module name'), regexp=r'[A-Za-z]\w*', default=project_name.lower()).input()
         company = CharInput(_('Company name'), max_length=255, blank=True, default=defaults.COMPANY).input()
         author = CharInput(_('Author name'), max_length=255, default=defaults.AUTHOR).input()
-        author_normalized = normalize_str(py3k_unicode(author))
-        company_normalized = normalize_str(py3k_unicode(company))
-        email = RegexpInput(_('Author e-mail'), default='%s@%s' % (author_normalized, company_normalized),
+        author_normalized = normalize_str(author)
+        company_normalized = normalize_str(company)
+        email = RegexpInput(_('Author e-mail'), default=u('%s@%s') % (author_normalized, company_normalized),
                             regexp=r'[\w_\-\.]+@[\w_\-\.]').input()
         license_ = ChoiceInput(_('License'), choices=licenses, blank=True, default='cecill b').input()
         pyversion = ChoiceInput(_('Minimum Python version'), choices=pyversions, default='2.7').input()
@@ -52,9 +53,9 @@ class BasePlugin(Plugin):
         translation = BooleanInput(_('Include translation (i18n) stuff'), default=True).input()
         context['translation'] = translation
         if translation:
-            filters['translate'] = py3k_unicode('_(\'{0}\')').format
+            filters['translate'] = u('_(\'{0}\')').format
         else:
-            filters['translate'] = py3k_unicode('\'{0}\'').format
+            filters['translate'] = u('\'{0}\'').format
         module_version = RegexpInput(_('Initial version'), regexp=r'[\w\.\-]', default='0.1').input()
         context['project_name'] = project_name
         context['module_name'] = module_name
@@ -73,27 +74,27 @@ class BasePlugin(Plugin):
         else:
             context['license_content'] = ''
         if py3compat == 'six':
-            filters['unicode'] = lambda x: py3k_unicode('six.u("{0}")').format(x.replace("\"", "\\\""))
-            filters['binary'] = lambda x: py3k_unicode('six.b("{0}")').format(x.replace("\"", "\\\""))
+            filters['unicode'] = lambda x: u('six.u("{0}")').format(x.replace("\"", "\\\""))
+            filters['binary'] = lambda x: u('six.b("{0}")').format(x.replace("\"", "\\\""))
             context['unicode'] = 'six.text_type'
             context['binary'] = 'six.binary_type'
             context['install_requires'].append('six')
             context['setup_requires'].append('six')
             context['tests_requires'].append('six')
         elif py3compat == 'source':
-            filters['unicode'] = lambda x: py3k_unicode('"{0}"').format(x.replace("\"", "\\\""))
-            filters['binary'] = lambda x: py3k_unicode('b"{0}"').format(x.replace("\"", "\\\""))
+            filters['unicode'] = lambda x: u('"{0}"').format(x.replace("\"", "\\\""))
+            filters['binary'] = lambda x: u('b"{0}"').format(x.replace("\"", "\\\""))
             context['unicode'] = 'str'
             context['binary'] = 'bytes'
         else:  # no compatibility or compatibility through 2to3
-            filters['unicode'] = lambda x: py3k_unicode('u"{0}"').format(x.replace("\"", "\\\""))
-            filters['binary'] = lambda x: py3k_unicode('"{0}"').format(x.replace("\"", "\\\""))
+            filters['unicode'] = lambda x: u('u"{0}"').format(x.replace("\"", "\\\""))
+            filters['binary'] = lambda x: u('"{0}"').format(x.replace("\"", "\\\""))
             context['unicode'] = 'unicode'
             context['binary'] = 'str'
         context['copyright_full'] = _('Copyright %(year)d, %(comp)s') % {'year': datetime.date.today().year,
                                                                          'comp': company}
         context['company'] = company
-        context['project_url'] = py3k_unicode('http://{0}/{1}.html').format(company, project_name)
+        context['project_url'] = u('http://{0}/{1}.html').format(company, project_name)
         context['email'] = email
         context['author'] = author
         context['module_version'] = module_version
